#
# Conditional build:
%bcond_without	doc	# Sphinx documentation
%bcond_with	tests	# unit tests [1 failure as of 2.2.17]

%define		module		django
Summary:	The web framework for perfectionists with deadlines
Summary(pl.UTF-8):	Szkielet WWW dla perfekcjonistów z ograniczeniami czasowymi
Name:		python3-%{module}
# stay on LTS line
# https://www.djangoproject.com/download/#supported-versions
Version:	5.2.1
Release:	1
License:	BSD
Group:		Libraries/Python
Source0:	https://media.djangoproject.com/releases/5.2/django-%{version}.tar.gz
# Source0-md5:	317174c6e0593c40e58ec1bd428b1091
URL:		https://www.djangoproject.com/
%if %(locale -a | grep -q '^C\.utf8$'; echo $?)
BuildRequires:	glibc-localedb-all
%endif
BuildRequires:	rpm-pythonprov
BuildRequires:	rpmbuild(find_lang) >= 1.40
BuildRequires:	rpmbuild(macros) >= 1.714
%{?with_doc:BuildRequires:	sphinx-pdg}
BuildRequires:	python3-devel >= 1:3.5
BuildRequires:	python3-setuptools
%if %{with tests}
BuildRequires:	python3-pytz
BuildRequires:	python3-selenium
BuildRequires:	python3-sqlparse >= 0.2.2
%endif
%if %{with doc}
BuildRequires:	sphinx-pdg >= 1.6.0
%endif
Suggests:	python3-MySQLdb
Suggests:	python3-PyGreSQL
Suggests:	python3-devel-tools
Conflicts:	python-django < 1.11.29
BuildArch:	noarch
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
Django is a high-level Python Web framework that encourages rapid
development and clean, pragmatic design.

%description -l pl.UTF-8
Django to wysokopoziomowy szkielet dla serwisów WWW w Pythonie
wspierający szybkie tworzenie i czysty, pragmatyczny projekt.

%package doc
Summary:	Documentation on Django
Summary(de.UTF-8):	Dokumentation zu Django
Summary(es.UTF-8):	Documentación para Django
Summary(fr.UTF-8):	Documentation sur Django
Summary(pl.UTF-8):	Dokumentacja do Django
Group:		Documentation

%description doc
Documentation on Django.

%description doc -l pl.UTF-8
Dokumentacja do Django.

%prep
%setup -q -n django-%{version}

%build
%py3_build_pyproject

%if %{with tests}
%{__python3} -m zipfile -e build-3/*.whl build-3-test
# use explicit plugins list for reliable builds (delete PYTEST_PLUGINS if empty)
PYTEST_DISABLE_PLUGIN_AUTOLOAD=1 \
PYTEST_PLUGINS= \
%{__python3} -m pytest -o pythonpath="$PWD/build-3-test" tests
%endif

%if %{with doc}
%{__make} -C docs html
%endif

%install
rm -rf $RPM_BUILD_ROOT

%py3_install_pyproject

%{__sed} -i -e '1s,/usr/bin/env python$,%{__python3},' $RPM_BUILD_ROOT%{py3_sitescriptdir}/django/conf/project_template/manage.py-tpl

%if %{with doc}
install -d $RPM_BUILD_ROOT%{_docdir}
ln -sf python-django-doc-%{version} $RPM_BUILD_ROOT%{_docdir}/python-django-doc
%endif

# don't package .po sources
find \
	%{?with_python2:$RPM_BUILD_ROOT%{py_sitescriptdir}/%{module}} \
	%{?with_python3:$RPM_BUILD_ROOT%{py3_sitescriptdir}/%{module}} \
	-name django.po -o \
	-name djangojs.po | xargs %{__rm} -v

%find_lang django --with-django --all-name

# fix after find-lang:
# - remove __pycache__ "language"
# - drop charsets from lang names (django uses non-standard _Charset instead of @charset)
grep -v __pycache__ <django.lang | \
	sed -e 's/lang(sr_Latn)/lang(sr)/;s/lang(zh_Hans)/lang(zh_CN)/;s/lang(zh_Hant)/lang(zh_TW)/' > %{name}.lang

%clean
rm -rf $RPM_BUILD_ROOT

%files -f %{name}.lang
%defattr(644,root,root,755)
%doc AUTHORS LICENSE README.rst
%attr(755,root,root) %{_bindir}/django-admin
%dir %{py3_sitescriptdir}/%{module}
%{py3_sitescriptdir}/%{module}/*.py
%{py3_sitescriptdir}/%{module}/__pycache__
%{py3_sitescriptdir}/%{module}/apps
%{py3_sitescriptdir}/%{module}/core
%{py3_sitescriptdir}/%{module}/db
%{py3_sitescriptdir}/%{module}/dispatch
%{py3_sitescriptdir}/%{module}/forms
%{py3_sitescriptdir}/%{module}/http
%{py3_sitescriptdir}/%{module}/middleware
%{py3_sitescriptdir}/%{module}/template
%{py3_sitescriptdir}/%{module}/templatetags
%{py3_sitescriptdir}/%{module}/test
%{py3_sitescriptdir}/%{module}/urls
%{py3_sitescriptdir}/%{module}/utils
%{py3_sitescriptdir}/%{module}/views

%dir %{py3_sitescriptdir}/%{module}/conf
%{py3_sitescriptdir}/%{module}/conf/*.py
%{py3_sitescriptdir}/%{module}/conf/__pycache__
%{py3_sitescriptdir}/%{module}/conf/app_template
%dir %{py3_sitescriptdir}/%{module}/conf/locale
%{py3_sitescriptdir}/%{module}/conf/locale/__init__.py
%{py3_sitescriptdir}/%{module}/conf/locale/__pycache__
%{py3_sitescriptdir}/%{module}/conf/project_template
%{py3_sitescriptdir}/%{module}/conf/urls

%dir %{py3_sitescriptdir}/%{module}/contrib
%{py3_sitescriptdir}/%{module}/contrib/*.py
%{py3_sitescriptdir}/%{module}/contrib/__pycache__
%dir %{py3_sitescriptdir}/%{module}/contrib/admin
%{py3_sitescriptdir}/%{module}/contrib/admin/*.py
%{py3_sitescriptdir}/%{module}/contrib/admin/__pycache__
%dir %{py3_sitescriptdir}/%{module}/contrib/admin/locale
%{py3_sitescriptdir}/%{module}/contrib/admin/migrations
%{py3_sitescriptdir}/%{module}/contrib/admin/static
%{py3_sitescriptdir}/%{module}/contrib/admin/templates
%{py3_sitescriptdir}/%{module}/contrib/admin/templatetags
%{py3_sitescriptdir}/%{module}/contrib/admin/views
%dir %{py3_sitescriptdir}/%{module}/contrib/admindocs
%{py3_sitescriptdir}/%{module}/contrib/admindocs/*.py
%{py3_sitescriptdir}/%{module}/contrib/admindocs/__pycache__
%dir %{py3_sitescriptdir}/%{module}/contrib/admindocs/locale
%{py3_sitescriptdir}/%{module}/contrib/admindocs/templates
%dir %{py3_sitescriptdir}/%{module}/contrib/auth
%{py3_sitescriptdir}/%{module}/contrib/auth/*.py
%{py3_sitescriptdir}/%{module}/contrib/auth/__pycache__
%{py3_sitescriptdir}/%{module}/contrib/auth/common-passwords.txt.gz
%{py3_sitescriptdir}/%{module}/contrib/auth/handlers
%dir %{py3_sitescriptdir}/%{module}/contrib/auth/locale
%{py3_sitescriptdir}/%{module}/contrib/auth/management
%{py3_sitescriptdir}/%{module}/contrib/auth/migrations
%{py3_sitescriptdir}/%{module}/contrib/auth/templates
%dir %{py3_sitescriptdir}/%{module}/contrib/contenttypes
%{py3_sitescriptdir}/%{module}/contrib/contenttypes/*.py
%{py3_sitescriptdir}/%{module}/contrib/contenttypes/__pycache__
%dir %{py3_sitescriptdir}/%{module}/contrib/contenttypes/locale
%{py3_sitescriptdir}/%{module}/contrib/contenttypes/management
%{py3_sitescriptdir}/%{module}/contrib/contenttypes/migrations
%dir %{py3_sitescriptdir}/%{module}/contrib/flatpages
%{py3_sitescriptdir}/%{module}/contrib/flatpages/*.py
%{py3_sitescriptdir}/%{module}/contrib/flatpages/__pycache__
%dir %{py3_sitescriptdir}/%{module}/contrib/flatpages/locale
%{py3_sitescriptdir}/%{module}/contrib/flatpages/migrations
%{py3_sitescriptdir}/%{module}/contrib/flatpages/templatetags
%dir %{py3_sitescriptdir}/%{module}/contrib/gis
%{py3_sitescriptdir}/%{module}/contrib/gis/*.py
%{py3_sitescriptdir}/%{module}/contrib/gis/__pycache__
%{py3_sitescriptdir}/%{module}/contrib/gis/admin
%{py3_sitescriptdir}/%{module}/contrib/gis/db
%{py3_sitescriptdir}/%{module}/contrib/gis/forms
%{py3_sitescriptdir}/%{module}/contrib/gis/gdal
%{py3_sitescriptdir}/%{module}/contrib/gis/geos
%dir %{py3_sitescriptdir}/%{module}/contrib/gis/locale
%{py3_sitescriptdir}/%{module}/contrib/gis/management
%{py3_sitescriptdir}/%{module}/contrib/gis/serializers
%{py3_sitescriptdir}/%{module}/contrib/gis/sitemaps
%{py3_sitescriptdir}/%{module}/contrib/gis/static
%{py3_sitescriptdir}/%{module}/contrib/gis/templates
%{py3_sitescriptdir}/%{module}/contrib/gis/utils
%dir %{py3_sitescriptdir}/%{module}/contrib/humanize
%{py3_sitescriptdir}/%{module}/contrib/humanize/*.py
%{py3_sitescriptdir}/%{module}/contrib/humanize/__pycache__
%dir %{py3_sitescriptdir}/%{module}/contrib/humanize/locale
%{py3_sitescriptdir}/%{module}/contrib/humanize/templatetags
%dir %{py3_sitescriptdir}/%{module}/contrib/messages
%{py3_sitescriptdir}/%{module}/contrib/messages/*.py
%{py3_sitescriptdir}/%{module}/contrib/messages/__pycache__
%{py3_sitescriptdir}/%{module}/contrib/messages/storage
%dir %{py3_sitescriptdir}/%{module}/contrib/postgres
%{py3_sitescriptdir}/%{module}/contrib/postgres/*.py
%{py3_sitescriptdir}/%{module}/contrib/postgres/__pycache__
%{py3_sitescriptdir}/%{module}/contrib/postgres/aggregates
%{py3_sitescriptdir}/%{module}/contrib/postgres/fields
%{py3_sitescriptdir}/%{module}/contrib/postgres/forms
%{py3_sitescriptdir}/%{module}/contrib/postgres/jinja2
%dir %{py3_sitescriptdir}/%{module}/contrib/postgres/locale
%{py3_sitescriptdir}/%{module}/contrib/postgres/templates
%dir %{py3_sitescriptdir}/%{module}/contrib/redirects
%{py3_sitescriptdir}/%{module}/contrib/redirects/*.py
%{py3_sitescriptdir}/%{module}/contrib/redirects/__pycache__
%dir %{py3_sitescriptdir}/%{module}/contrib/redirects/locale
%{py3_sitescriptdir}/%{module}/contrib/redirects/migrations
%dir %{py3_sitescriptdir}/%{module}/contrib/sessions
%{py3_sitescriptdir}/%{module}/contrib/sessions/*.py
%{py3_sitescriptdir}/%{module}/contrib/sessions/__pycache__
%{py3_sitescriptdir}/%{module}/contrib/sessions/backends
%dir %{py3_sitescriptdir}/%{module}/contrib/sessions/locale
%{py3_sitescriptdir}/%{module}/contrib/sessions/management
%{py3_sitescriptdir}/%{module}/contrib/sessions/migrations
%{py3_sitescriptdir}/%{module}/contrib/sitemaps
%dir %{py3_sitescriptdir}/%{module}/contrib/sites
%{py3_sitescriptdir}/%{module}/contrib/sites/*.py
%{py3_sitescriptdir}/%{module}/contrib/sites/__pycache__
%dir %{py3_sitescriptdir}/%{module}/contrib/sites/locale
%{py3_sitescriptdir}/%{module}/contrib/sites/migrations
%{py3_sitescriptdir}/%{module}/contrib/staticfiles
%{py3_sitescriptdir}/%{module}/contrib/syndication

%{py3_sitescriptdir}/%{module}-%{version}*.dist-info

%if %{with doc}
%files doc
%defattr(644,root,root,755)
%doc docs/_build/html/{_images,_modules,_static,faq,howto,internals,intro,misc,ref,releases,topics,*.html,*.js}
%{_docdir}/python-django-doc
%endif
%changelog
* Tue May 27 2025 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/python3-django.git;a=log;h=master

* Tue May 27 2025 Jan Rękorajski <baggins@pld-linux.org> cb5adfb
- up to 5.2.1

* Tue Mar 11 2025 Jan Rękorajski <baggins@pld-linux.org> 89e96dd
- doc/test rebuild for python 3.13

* Mon Mar 10 2025 Jan Rękorajski <baggins@pld-linux.org> d057ab8
- python 3.13 rebuild

* Mon Apr 25 2022 Jakub Bogusz <qboosh@pld-linux.org> e91d541
- updated to 2.2.28 (the last Django 2 - EOL anyway)

* Wed Mar 30 2022 Jan Rękorajski <baggins@pld-linux.org> 3fc07b0
- rebuild with tests and docs

* Sat Mar 26 2022 Jan Rękorajski <baggins@pld-linux.org> fd28c87
- rebuild with python 3.10

* Sat Feb 27 2021 Jan Rękorajski <baggins@pld-linux.org> 078b77c
- release 2 (by relup.sh)

* Sat Jan 30 2021 Jakub Bogusz <qboosh@pld-linux.org> 78a8f56
- updated to 2.2.17 for python 3.5+ as python3-django.spec
- removed obsolete sphinx patch

* Fri Jan 29 2021 Jakub Bogusz <qboosh@pld-linux.org> 505c28f
- updated to 1.11.29
- removed obsolete python3.7 patch
- added sphinx patch (adjust for Sphinx 2+)

* Mon Oct 28 2019 Jan Rękorajski <baggins@pld-linux.org> 6818b92
- rebuild with python 3.8
- release 2 (by relup.sh)

* Wed Sep 26 2018 Jacek Konieczny <j.konieczny@eggsoft.pl> db994b0
- Version: 1.11.15, Python 3.7 compat fix

* Sun Jul 01 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> 443aa58
- python 3.7 rebuild
- release 2 (by relup.sh)

* Sun May 27 2018 Jakub Bogusz <qboosh@pld-linux.org> e6d3960
- disable tests by default (some fail randomly)

* Sun May 27 2018 Jakub Bogusz <qboosh@pld-linux.org> 04256ad
- updated to 1.11.13
- run unit tests
- use find-lang 1.40

* Sun Apr 23 2017 Elan Ruusamäe <glen@delfi.ee> a5a1a53
- find lang dep

* Sun Apr 23 2017 Elan Ruusamäe <glen@delfi.ee> 3890c26
- package missing top level dir

* Sun Apr 23 2017 Elan Ruusamäe <glen@delfi.ee> dd1957b
- %lang tag language resources

* Sun Apr 23 2017 Elan Ruusamäe <glen@delfi.ee> f0e58eb
- up to 1.11 LTS

* Thu Dec 29 2016 Arkadiusz Miśkiewicz <arekm@maven.pl> 0be730c
- python 3.6
- release 2 (by relup.sh)

* Thu Sep 29 2016 Mariusz Mazur <mmazur@axeos.com> 6b608f6
- Up to 1.8.15

